#! /usr/bin/env python
# -*- coding: utf-8 -*-

from clint import args
from clint.textui import progress
import multiprocessing

"""
    args.all yields all the command line arguments in list.
    Also expands ~ 
    args.grouped yield --d or -d with passed params
"""

def main():
    print "welcome to test"
