# -*- coding: utf-8

"""
crunch
``````
main interface for crunch

"""

from __future__ import absolute_import


#Meta data

__title__ = 'crunch'
__version__ = '0.0.2.1'
__build__ = 0x00002
__author__ = 'kracekumar'
__license__ = 'ISC'
__copyright__ = 'Copyright 2012 kracekumar'
__docformat__ = 'restructuredtext'



